/******************************************************************************
* Include files
******************************************************************************/
#include <avr/io.h>
#include <util/atomic.h>
#include "eeprom.h"

/******************************************************************************
* Macros
******************************************************************************/


/******************************************************************************
* Constants
******************************************************************************/


/******************************************************************************
* Global Variables
******************************************************************************/


/******************************************************************************
* External Variables
******************************************************************************/


/******************************************************************************
* Local Function Declarations
******************************************************************************/


/******************************************************************************
* Local Function Definitions
******************************************************************************/


/******************************************************************************
* Global Function Definitions
******************************************************************************/

/******************************************************************************
* Function: EEPROM_write(unsigned int uiAddress, unsigned char ucData)
* Description: EEPROM-ba rs
* Input: cm, karakter
* Output: hibakd (0 - OK, 1 - hibs cm)
* Notes:
******************************************************************************/
uint8_t EEPROM_write(uint16_t uiAddress, uint8_t ucData)
{
	if(uiAddress>0xFFF)
	  return 1;
	/* Wait for completion of previous write */
	while(EECR & (1<<EEWE));
	/* Set up address and data registers */
	EEAR = uiAddress;
	EEDR = ucData;
	// Interrupts are disabled within the block and re-enabled at the end
	ATOMIC_BLOCK(ATOMIC_RESTORESTATE)
	{
	  /* Write logical one to EEMWE */
	  EECR |= (1<<EEMWE);
	  /* Start eeprom write by setting EEWE */
	  EECR |= (1<<EEWE);
	}
	
	return 0;
}


/******************************************************************************
* Function: unsigned char EEPROM_read(unsigned int uiAddress)
* Description: EEPROM-bl olvass
* Input: cm
* Output: karakter, hibakd (0 - OK, 1 - hibs cm)
* Notes:
******************************************************************************/
uint8_t EEPROM_read(uint16_t uiAddress, uint8_t *ucData)
{
	/* Bad address */
	if(uiAddress>0xFFF)
	return 1;
	/* Wait for completion of previous write */
	while(EECR & (1<<EEWE));
	/* Set up address register */
	EEAR = uiAddress;
	/* Start eeprom read by writing EERE */
	EECR |= (1<<EERE);
	*ucData=EEDR;
	/* Return OK */
	return 0;
}